@@ -6,3 +6,5 @@ library(qrandom)
 test_check('qrandom', filter = "qrandom")
 test_check('qrandom', filter = "qrandomunif")
 test_check('qrandom', filter = "qrandomnorm")
+test_check('qrandom', filter = "qUUID")
+test_check('qrandom', filter = "qrandommaxint")
